@@ -10,8 +10,7 @@ const (
 	DefaultRetriesSynScan     = 3
 	DefaultRetriesConnectScan = 3
 
-	ExternalTargetForTune = "8.8.8.8"
-
-	SynScan     = "s"
-	ConnectScan = "c"
+	SynScan             = "s"
+	ConnectScan         = "c"
+	DefautStatsInterval = 5
 )
